@@ -30,3 +30,5 @@ require 'commander/runner'
 require 'commander/command'
 require 'commander/help_formatters'
 require 'commander/platform'
+require 'commander/methods'
+require 'commander/configure'
